# CentroGeo - SEDEMA: Áreas Verdes
Este repositorio es un conjunto de códigos desarrollado por [**CentroGeo**](geoint.mx) para calcular la cobertura de vegetación en un conjunto de áreas de interés utilizando los productos L2A de la plataforma sentinel-2.


## Requerimientos
Se recomienda utilizar Ubuntu o Debian/GNU Linux para utilizar este repositorio.
* Instalar dependencias.
```bash
	apt-get install git python3-pip libgdal-dev parallel
	sudo pip3 install sentinelsat
	pip3 install GDAL==$(gdal-config --version) --global-option=build_ext --global-option="-I/usr/include/gdal" 
```

* Instalar el repositorio [**Geosentinel**](http://gitlab.geoint.mx/mario.chirinos/GeoSentinel).
```bash
	mkdir git-sedema
	cd git-sedema
	git clone http://gitlab.geoint.mx/mario.chirinos/GeoSentinel.git
```
* Agregar el directorio *scripts* al la variable de ambiente PATH
```bash
	export PATH="$HOME/git-sedema/GeoSentinel/geosentinel/:$PATH"
```
* Clonar este repositorio.
```bash	
	git clone http://gitlab.geoint.mx/mario.chirinos/sedema-av.git
```
* Agregar el directorio *scripts* al la variable de ambiente PATH
```bash
	export PATH="$HOME/git-sedema/sedema-av/scripts/:$PATH"
```
## Configuración

### Archivo de Configuración
El comportamiento de los códigos esta controlado por el archivo **data/settings.json**, este contiene los parámetros de configuración para el análisis. *startDate* y *endDate* se refieren al rango de fechas para realizar el analisis, *clouds* es e porcentaje de tolerancia de nubes dentro de la imagen, *productsDir* es la ubicación donde serán guardadas las imágenes satelitáles que se descargan y *username* y *password* se refieren a los datos de acceso de una cuenta de [**The Copernicus Open Access Hub**](https://scihub.copernicus.eu/), la cual es necesaria pora tener acceso a descargar las imágenes de Sentine-2.
```json
{
	"platform": "Sentinel-2",
	"productLevel":"L2A",
	"startDate": "20190101",
	"endDate": "20200101",
	"clouds":"4",
	"productsDir":"~/resultados/sentinelImages/",
	"username":"",
	"password":""
}


```
### Polígonos de Análisis
Las áreas de análisis están dadas por el archivo **data/poligonos-CDMX.csv** el cual debe de contener las columnas CVEGEO, WKT y WKT2. La columna CVEGEO es el identificador del Área, WKT es el polígono que define el área de interés en formato *Well Known Text* y WKT2 es un segundo polígono el cual se resta de WKT para obtener un segundo estimado del área verde.

## Uso
```bash
	mkdir ~/resultados
	cp ~/git-sedema/sedema-av/data/settings.json ~/resultados/
	cp ~/git-sedema/sedema-av/data/poligonos-CDMX.csv ~/resultados/
	cd ~/resultados/
	mkdir 2020
	GI_runAnalisis.sh poligonos-CDMX.csv settings.json 2020
```
## Datos Generados
Los datos generados se encuentran en dos archivos **resultados/areamax_4.csv** y **resultados/morphology_4.csv**
* areamax_4.csv: Este archivo contiene los datos del área verde para cada una de las regiones. 
* morphology_4.csv: Este archivo contiene los índices morfológicos obtenidos para cada región.

## Modulos
### GI_runAnalisis.sh
Este es el archivo principal que se usa para realizar el análisis. Este códigos crea un directorio para cada área de análisis y llama al codigo **GI_L2ASCL_AreaProcessing.sh**.

```bash
	GI_runAnalisis.sh poligonos-CDMX.csv settings.json 2020
```
### GI_L2ASCL_AreaProcessing.sh

### 
